componenttools.get_likely_multiplier_of_components
==================================================

.. autofunction:: abjad.tools.componenttools.get_likely_multiplier_of_components.get_likely_multiplier_of_components
